# mobotix-finder
Mobotix camera finder using ZoomEye

## Usage:

- Install: `pip install mobotix-finder`
- Set `ZOOMEYE_API_KEY` or `ZOOMEYE_USERNAME` and `ZOOMEYE_PASSWORD` environment variables
- `find-mobotix ~/Downloads/mobotix`
- For more options run `find-mobotix --help`

Please use responsibly!
